==> cmsmadesimple-1.10.3-full.tar.gz: modules/MicroTiny/lang/ext/sr_YU.php <==
<?php
$lang['show_statusbar'] = 'Prikaži statusnu liniju';
$lang['help_show_statusbar'] = 'Omogućava prikaz statusne linije na dnu WYSIWYG editora.  Primenljivo je samo u administratorskom delu sajta.';
$lang['allow_resize'] = 'Dozvoli menjanje veličine';
$lang['help_allow_resize'] = 'Dozvoljava menjanje veličine WYSIWYG editora. Zahteva da bude prikazana i statusna linija';
$lang['view_html'] = 'Prikaži HTML kod';
$lang['friendlyname'] = 'MicroTiny WYSIWYG editor teksta';
$lang['help'] = '<strong>&Scaron;ta ovaj modul radi?</strong>
<br/>
MicroTiny je mala verzija TinyMCE-editora, koji je bio kori&scaron;ten kao glavni wysiwyg urednik CMS Made Simple-a.
Pruža samo najosnovnije funkcije uređivanja, ali je i dalje moćan alat koji
omogućava lake izmene sadržaja stranica.';
$lang['example'] = 'MicroTiny primer';
$lang['settings'] = 'Pode&scaron;avanja';
$lang['youareintext'] = 'Vi ste u';
$lang['dimensions'] = '&Scaron;xV';
$lang['size'] = 'Veličina';
$lang['filepickertitle'] = 'Izbor datoteke';
$lang['cmsmslinker'] = 'CMSMS  Linker';
$lang['tmpnotwritable'] = 'Konfiguracija nije mogla biti upisana u tmp direktorij. Molimo Vas da popravite to!';
$lang['css_styles_text'] = 'CSS stilovi';
$lang['css_styles_help'] = 'CSS nazivi koje ovde navedete biće dodati u listu u editoru. Ako ostavite ovo polje prazno, lista stilova neće biti prikazana (podrazumevano pona&scaron;anje).';
$lang['css_styles_help2'] = 'Stilovi mogu biti iskljućivo nazivi klase, ili naziv klase praćen novim nazivom, koji će biti prikazan u editoru.
Stavke moraju biti razdvojene zarezom ili novim redom.
<br/>Primer: <code>mystyle1, My style name=mystyle</code>
<br/>Rezultat: lista sa dva stila, &#039;mystyle1&#039; i &#039;My style name&#039;.
<br/>Ovo se koristi uglavnom da bi se sadržaju koji je u editoru (tekst, slike i sl.) dodelio poseban stil, koji nema globalni opseg. Na primer, za sliku, može se definisati klasa sa okvirom i klasa bez okvira, pa korisnik tokom pravljenja sadržaja odlučuje kako će njegova slika izgledati na sajtu.
<br/><strong>Napomena:</strong> Ne proverava se da li klase sa navedenim nazivima zaista postoje u Stilovima teme. Veruje Vam se na reč. :)';
$lang['usestaticconfig_text'] = 'Koristi statičku konfiguraciju';
$lang['usestaticconfig_help'] = 'Generi&scaron;e statičku konfiguracionu datoteku umesto dinamične. To bolje radi na nekim serverima (na primer kada pokreće PHP kao CGI)';
$lang['allowimages_text'] = 'Dozvoli slike';
$lang['allowimages_help'] = 'Prikazuje dugme za ubacivanje slike na traci sa alatkama, &scaron;to omogućava ubacivanje slike u sadržaj';
$lang['settingssaved'] = 'Pode&scaron;avanja su sačuvana';
$lang['savesettings'] = 'Sačuvaj pode&scaron;avanja';
$lang['utma'] = '156861353.1702067667.1318973760.1318973760.1319008264.2';
$lang['utmz'] = '156861353.1318973760.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
$lang['qca'] = 'P0-91463818-1318971343774';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> cmsmadesimple-1.11.10-full.tar.gz: modules/MicroTiny/lang/ext/sr_YU.php <==
<?php
$lang['admindescription'] = 'Upro&scaron;ćena, ali i dalje vrlo moćna verzija TinyMCE WYSIWYG editora.';
$lang['force_blackonwhite'] = 'Uvek prikazuj crni tekst na beloj pozadini';
$lang['help_force_blackonwhite'] = 'Uvek prikazuje crni tekst na beloj pozadini, zanemarujući trenutni &Scaron;ablon i Stil sajta. Ovo može pobolj&scaron;ati čitljivost teksta u WYSIWYG editoru na onim sajtovima koji imaju tamnu pozadinu a svetao tekst.';
$lang['strip_background'] = 'Zanemari CSS pode&scaron;avanja pozadine sajta';
$lang['help_strip_background'] = 'Ovo će možda pobolj&scaron;ati čitljivost teksta u WYSIWYG editoru na onim sajtovima koji imaju tamnu pozadinu a svetao tekst.';
$lang['show_statusbar'] = 'Prikaži statusnu liniju';
$lang['help_show_statusbar'] = 'Omogućava prikaz statusne linije na dnu WYSIWYG editora.  Primenljivo je samo u administratorskom delu sajta.';
$lang['allow_resize'] = 'Dozvoli menjanje veličine';
$lang['help_allow_resize'] = 'Dozvoljava menjanje veličine WYSIWYG editora. Zahteva da bude prikazana i statusna linija';
$lang['view_html'] = 'Prikaži HTML kod';
$lang['friendlyname'] = 'MicroTiny WYSIWYG editor teksta';
$lang['help'] = '<strong>&Scaron;ta ovaj modul radi?</strong>
<br/>
MicroTiny je mala verzija TinyMCE-editora, koji je bio kori&scaron;ten kao glavni wysiwyg urednik CMS Made Simple-a.
Pruža samo najosnovnije funkcije uređivanja, ali je i dalje moćan alat koji
omogućava lake izmene sadržaja stranica.';
$lang['example'] = 'MicroTiny primer';
$lang['settings'] = 'Pode&scaron;avanja';
$lang['youareintext'] = 'Vi ste u';
$lang['dimensions'] = '&Scaron;xV';
$lang['size'] = 'Veličina';
$lang['filepickertitle'] = 'Izbor datoteke';
$lang['cmsmslinker'] = 'CMSMS  Linker';
$lang['tmpnotwritable'] = 'Konfiguracija nije mogla biti upisana u tmp direktorij. Molimo Vas da popravite to!';
$lang['css_styles_text'] = 'CSS stilovi';
$lang['css_styles_help'] = 'CSS nazivi koje ovde navedete biće dodati u listu u editoru. Ako ostavite ovo polje prazno, lista stilova neće biti prikazana (podrazumevano pona&scaron;anje).';
$lang['css_styles_help2'] = 'Stilovi mogu biti iskljućivo nazivi klase, ili naziv klase praćen novim nazivom, koji će biti prikazan u editoru.
Stavke moraju biti razdvojene zarezom ili novim redom.
<br/>Primer: <code>mystyle1, My style name=mystyle</code>
<br/>Rezultat: lista sa dva stila, &#039;mystyle1&#039; i &#039;My style name&#039;.
<br/>Ovo se koristi uglavnom da bi se sadržaju koji je u editoru (tekst, slike i sl.) dodelio poseban stil, koji nema globalni opseg. Na primer, za sliku, može se definisati klasa sa okvirom i klasa bez okvira, pa korisnik tokom pravljenja sadržaja odlučuje kako će njegova slika izgledati na sajtu.
<br/><strong>Napomena:</strong> Ne proverava se da li klase sa navedenim nazivima zaista postoje u Stilovima teme. Veruje Vam se na reč. :)';
$lang['usestaticconfig_text'] = 'Koristi statičku konfiguraciju';
$lang['usestaticconfig_help'] = 'Generi&scaron;e statičku konfiguracionu datoteku umesto dinamične. To bolje radi na nekim serverima (na primer kada pokreće PHP kao CGI)';
$lang['allowimages_text'] = 'Dozvoli slike';
$lang['allowimages_help'] = 'Prikazuje dugme za ubacivanje slike na traci sa alatkama, &scaron;to omogućava ubacivanje slike u sadržaj';
$lang['settingssaved'] = 'Pode&scaron;avanja su sačuvana';
$lang['savesettings'] = 'Sačuvaj pode&scaron;avanja';
$lang['utma'] = '156861353.442583343.1341176366.1341523989.1342131109.5';
$lang['utmz'] = '156861353.1341176366.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
